@@ -2,7 +2,8 @@ use crate::{
     components::{
         ChangesComponent, CommandBlocking, CommandInfo,
         CommitComponent, Component, DiffComponent, DrawableComponent,
-        HelpComponent, MsgComponent, ResetComponent,
+        FileTreeItemKind, HelpComponent, MsgComponent,
+        ResetComponent,
     },
     keys,
     queue::{InternalEvent, NeedsUpdate, Queue},
@@ -16,7 +17,7 @@ use crossbeam_channel::Sender;
 use crossterm::event::Event;
 use itertools::Itertools;
 use log::trace;
-use std::{borrow::Cow, path::Path};
+use std::borrow::Cow;
 use strings::commands;
 use tui::{
     backend::Backend,
@@ -177,7 +178,9 @@ impl App {
                     self.switch_focus(Focus::WorkDir)
                 }
                 keys::FOCUS_STAGE => self.switch_focus(Focus::Stage),
-                keys::FOCUS_RIGHT => self.switch_focus(Focus::Diff),
+                keys::FOCUS_RIGHT if self.can_focus_diff() => {
+                    self.switch_focus(Focus::Diff)
+                }
                 keys::FOCUS_LEFT => {
                     self.switch_focus(match self.diff_target {
                         DiffTarget::Stage => Focus::Stage,
@@ -225,6 +228,14 @@ impl App {
     pub fn is_quit(&self) -> bool {
         self.do_quit
     }
+
+    fn can_focus_diff(&self) -> bool {
+        match self.focus {
+            Focus::WorkDir => self.index_wd.is_file_seleted(),
+            Focus::Stage => self.index.is_file_seleted(),
+            _ => false,
+        }
+    }
 }
 
 // private impls
@@ -259,11 +270,12 @@ impl App {
             DiffTarget::WorkingDir => (&self.index_wd, false),
         };
 
-        if let Some(i) = idx.selection() {
-            Some((i.path, is_stage))
-        } else {
-            None
+        if let Some(item) = idx.selection() {
+            if let FileTreeItemKind::File(i) = item.kind {
+                return Some((i.path, is_stage));
+            }
         }
+        None
     }
 
     fn update_commands(&mut self) {
@@ -287,7 +299,7 @@ impl App {
         loop {
             let front = self.queue.borrow_mut().pop_front();
             if let Some(e) = front {
-                flags.insert(self.process_internal_event(&e));
+                flags.insert(self.process_internal_event(e));
             } else {
                 break;
             }
@@ -299,35 +311,45 @@ impl App {
 
     fn process_internal_event(
         &mut self,
-        ev: &InternalEvent,
+        ev: InternalEvent,
     ) -> NeedsUpdate {
         let mut flags = NeedsUpdate::empty();
         match ev {
-            InternalEvent::ResetFile(p) => {
-                if sync::reset_workdir(CWD, Path::new(p.as_str())) {
+            InternalEvent::ResetItem(reset_item) => {
+                if reset_item.is_folder {
+                    if sync::reset_workdir_folder(
+                        CWD,
+                        reset_item.path.as_str(),
+                    ) {
+                        flags.insert(NeedsUpdate::ALL);
+                    }
+                } else if sync::reset_workdir_file(
+                    CWD,
+                    reset_item.path.as_str(),
+                ) {
                     flags.insert(NeedsUpdate::ALL);
                 }
             }
-            InternalEvent::ConfirmResetFile(p) => {
-                self.reset.open_for_path(p);
+            InternalEvent::ConfirmResetItem(reset_item) => {
+                self.reset.open_for_path(reset_item);
                 flags.insert(NeedsUpdate::COMMANDS);
             }
             InternalEvent::AddHunk(hash) => {
                 if let Some((path, is_stage)) = self.selected_path() {
                     if is_stage {
-                        if sync::unstage_hunk(CWD, path, *hash) {
+                        if sync::unstage_hunk(CWD, path, hash) {
                             flags.insert(NeedsUpdate::ALL);
                         }
-                    } else if sync::stage_hunk(CWD, path, *hash) {
+                    } else if sync::stage_hunk(CWD, path, hash) {
                         flags.insert(NeedsUpdate::ALL);
                     }
                 }
             }
             InternalEvent::ShowMsg(msg) => {
-                self.msg.show_msg(msg);
+                self.msg.show_msg(msg.as_str());
                 flags.insert(NeedsUpdate::ALL);
             }
-            InternalEvent::Update(u) => flags.insert(*u),
+            InternalEvent::Update(u) => flags.insert(u),
         };
 
         flags
@@ -381,7 +403,7 @@ impl App {
                 ));
                 res.push(CommandInfo::new(
                     commands::STATUS_FOCUS_RIGHT,
-                    true,
+                    self.can_focus_diff(),
                     main_cmds_available && !focus_on_diff,
                 ));
             }
