@@ -24,6 +24,8 @@ pub const EXIT_2: KeyEvent = no_mod(KeyCode::Char('q'));
 pub const CLOSE_MSG: KeyEvent = no_mod(KeyCode::Enter);
 pub const OPEN_COMMIT: KeyEvent = no_mod(KeyCode::Char('c'));
 pub const OPEN_HELP: KeyEvent = no_mod(KeyCode::Char('h'));
+pub const MOVE_LEFT: KeyEvent = no_mod(KeyCode::Left);
+pub const MOVE_RIGHT: KeyEvent = no_mod(KeyCode::Right);
 pub const MOVE_UP: KeyEvent = no_mod(KeyCode::Up);
 pub const MOVE_DOWN: KeyEvent = no_mod(KeyCode::Down);
 pub const STATUS_STAGE_FILE: KeyEvent = no_mod(KeyCode::Enter);
